# MLSCAT

A small cat that helps you enjoy your side channel attack journey!

## Features

- Read Datasets: We provide a simple method to read some exist datasets(it would be better if there have the same structure!
- Cal Rank: try to give the key and result nparray
- Simple Attack: CPA, DPA.
- quickly data preprocessing.

example:

```python
import mlscat as cat

print(cat.__version__)

# 0.1
```

## How to install❓

To install mlscat, just follow one steps:

`pip install mlscat`

## Benefits

- Reduce Workload.
- Increase hair volume.

## 引用

如果您在研究中使用了本工具库，请在您的文章中引用以下文献：

```bibtex
@software{hou_2025_15074706,
  author       = {Hou, Minghui},
  title        = {Mlscat-Machine Learning based Side Channel Analysis Tools},
  month        = mar,
  year         = 2025,
  publisher    = {M0nk3y},
  doi          = {10.5281/zenodo.15074706},
  url          = {https://doi.org/10.5281/zenodo.15074706}
}